@@ -233,8 +233,8 @@ def get_metadata_types(cls):
     Return map from key -> type for the metadata fields in the given bundle class.
     e.g.
        'request_time' -> 'basestring'
-       'time' -> 'duration'
-       'tags' -> 'list'
+       'time'         -> 'duration'
+       'tags'         -> 'list'
 
     Possible types: 'int', 'float', 'list', 'bool', 'duration',
                     'size', 'date', 'basestring'
@@ -248,6 +248,17 @@ def get_metadata_types(cls):
     }
 
 
+def get_metadata_descriptions(cls):
+    """
+    Return map from key -> description for the metadata fields in the given bundle class.
+    e.g.
+       'request_time' -> 'Amount of time (e.g., 3, 3m, 3h, 3d)...'
+       'time'         -> 'Amount of wall clock time (seconds)...'
+       'tags'         -> 'Space-separated list of tags...'
+    """
+    return {spec.key: spec.description for spec in cls.METADATA_SPECS}
+
+
 def request_lines(worksheet_info):
     """
     Input: worksheet_info
