@@ -1,7 +1,7 @@
 from io import SEEK_SET, SEEK_CUR, SEEK_END, BytesIO
 
 from codalab.worker.un_gzip_stream import BytesBuffer
-from codalab.lib.beam.ratarmount import FileInfo, SQLiteIndexedTar
+from ratarmountcore import FileInfo, SQLiteIndexedTar
 
 
 class TarFileStream(BytesIO):
@@ -32,7 +32,6 @@ class TarFileStream(BytesIO):
         the tar archive.
         """
         contents = self.tf.read(
-            path="",
             fileInfo=self.finfo,
             size=self.finfo.size
             if num_bytes is None
